package com.ruoyi.dz.service;

import java.util.List;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.enums.ExamType;
import com.ruoyi.dz.domain.DzControl;

/**
 * 单招省份状态Service接口
 * 
 * @author ruoyi
 * @date 2025-09-12
 */
public interface IDzControlService 
{
    /**
     * 查询单招省份状态
     * 
     * @param id 单招省份状态主键
     * @return 单招省份状态
     */
    public DzControl selectDzControlById(Long id);

    /**
     * 查询单招省份状态列表
     * 
     * @param dzControl 单招省份状态
     * @return 单招省份状态集合
     */
    public List<DzControl> selectDzControlList(DzControl dzControl);

    /**
     * 新增单招省份状态
     * 
     * @param dzControl 单招省份状态
     * @return 结果
     */
    public int insertDzControl(DzControl dzControl);

    /**
     * 修改单招省份状态
     * 
     * @param dzControl 单招省份状态
     * @return 结果
     */
    public int updateDzControl(DzControl dzControl);

    /**
     * 批量删除单招省份状态
     * 
     * @param ids 需要删除的单招省份状态主键集合
     * @return 结果
     */
    public int deleteDzControlByIds(Long[] ids);

    /**
     * 删除单招省份状态信息
     * 
     * @param id 单招省份状态主键
     * @return 结果
     */
    public int deleteDzControlById(Long id);


    public DzControl selectDzControl(SysUser user);

    public DzControl selectDzControl(String location, ExamType examType);
}
